==============
Using futurist
==============

.. toctree::
   :maxdepth: 2

   features
   examples

.. history contains a lot of sections, toctree with maxdepth 1 is used.
.. toctree::
   :maxdepth: 1

   history
